# About the Project

## Help

Where to ask questions:

* [Netreplica Discord Server](https://discord.gg/M2SkgSdKht)
* [NetDev Community Slack - #netreplica](https://netdev-community.slack.com/archives/C054GKBC4LB)
* [GitHub Issues](https://github.com/netreplica/nrx/issues)

[![Discord](https://img.shields.io/discord/1075106069862416525?label=discord)](https://discord.gg/M2SkgSdKht)

## Contributing

We welcome contributions! See our [Contributing Guide](./development/contributing.md) for details.

## Original Idea and Implementation

This is a [NANOG-87 Hackathon](https://www.nanog.org/events/nanog-87-hackathon/) project.

View the original project [slides](https://docs.google.com/presentation/d/1-WcKsDuaFh3tozmTdTxGYXjMFuthRyevsRZbIc2j2Kw/edit?usp=sharing).

### Project Team

* [Alex Bortok](https://github.com/bortok)
* [Chip Gwyn](https://github.com/chipgwyn)
* [Toni Yannick Kalombo](https://github.com/tonikalombo)

### Inspiration

The implementation is inspired by [ContainerLab random labs](https://gist.github.com/renatoalmeidaoliveira/fdb772a5a02f3cfc0b5fbe7e8b7586a2) by [Renato Almeida de Oliveira](https://github.com/renatoalmeidaoliveira).

## Device Configuration Export

We added capabilities to export device configurations at [NANOG-88 Hackathon](https://www.nanog.org/events/nanog-88-hackathon/).

### Project Team

* [Alex Bortok](https://www.linkedin.com/in/bortok/)
* [Mau Rojas](https://www.linkedin.com/in/pinrojas/)
* [Ahmed Elmokashfi](https://www.linkedin.com/in/elmokashfi/)

### Project Demo

Watch [the demo of the project on YouTube](https://youtu.be/cP8PUr306ZM):

[![Watch the video](https://img.youtube.com/vi/cP8PUr306ZM/maxresdefault.jpg)](https://youtu.be/cP8PUr306ZM)

## Acknowledgments

Special thanks to:

* NANOG for hosting the hackathons that started this project
* The NetBox community for their excellent DCIM platform
* Contributors and users who provide feedback and improvements

## See Also

* [License Information](license.md)
* [Project Repository](https://github.com/netreplica/nrx)
* [Release History](https://github.com/netreplica/nrx/releases)
